"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.apploadbalancer.v1.logging_pb2
import yandex.cloud.apploadbalancer.v1.target_group_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LoadBalancer(google.protobuf.message.Message):
    """An application load balancer resource.
    For details about the concept, see [documentation](/docs/application-load-balancer/concepts/application-load-balancer).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[LoadBalancer._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: LoadBalancer._Status.ValueType  # 0
        CREATING: LoadBalancer._Status.ValueType  # 1
        """The application load balancer is being created."""
        STARTING: LoadBalancer._Status.ValueType  # 2
        """The application load balancer is being started."""
        ACTIVE: LoadBalancer._Status.ValueType  # 3
        """The application load balancer is active and sends traffic to the targets."""
        STOPPING: LoadBalancer._Status.ValueType  # 4
        """The application load balancer is being stopped."""
        STOPPED: LoadBalancer._Status.ValueType  # 5
        """The application load balancer is stopped and doesn't send traffic to the targets."""
        DELETING: LoadBalancer._Status.ValueType  # 6
        """The application load balancer is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: LoadBalancer.Status.ValueType  # 0
    CREATING: LoadBalancer.Status.ValueType  # 1
    """The application load balancer is being created."""
    STARTING: LoadBalancer.Status.ValueType  # 2
    """The application load balancer is being started."""
    ACTIVE: LoadBalancer.Status.ValueType  # 3
    """The application load balancer is active and sends traffic to the targets."""
    STOPPING: LoadBalancer.Status.ValueType  # 4
    """The application load balancer is being stopped."""
    STOPPED: LoadBalancer.Status.ValueType  # 5
    """The application load balancer is stopped and doesn't send traffic to the targets."""
    DELETING: LoadBalancer.Status.ValueType  # 6
    """The application load balancer is being deleted."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    LISTENERS_FIELD_NUMBER: builtins.int
    ALLOCATION_POLICY_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    AUTO_SCALE_POLICY_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the application load balancer. Generated at creation time."""
    name: builtins.str
    """Name of the application load balancer. The name is unique within the folder."""
    description: builtins.str
    """Description of the application load balancer."""
    folder_id: builtins.str
    """ID of the folder that the application load balancer belongs to."""
    status: global___LoadBalancer.Status.ValueType
    """Status of the application load balancer."""
    region_id: builtins.str
    """ID of the region that the application load balancer is located at."""
    network_id: builtins.str
    """ID of the network that the application load balancer belongs to."""
    log_group_id: builtins.str
    """ID of the log group that stores access logs of the application load balancer.

    The logs can be accessed using a Cloud Functions [trigger for Cloud Logs](/docs/functions/operations/trigger/cloud-logging-trigger-create).
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Application load balancer labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).
        """

    @property
    def listeners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Listener]:
        """Listeners that belong to the application load balancer.

        For details about the concept, see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#listener).
        """

    @property
    def allocation_policy(self) -> global___AllocationPolicy:
        """Locality settings of the application load balancer.

        For details about the concept, see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#lb-location).
        """

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """ID's of the security groups attributed to the application load balancer.

        For details about the concept,
        see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#security-groups).
        """

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def auto_scale_policy(self) -> global___AutoScalePolicy:
        """Scaling settings of the application load balancer.

        The scaling settings relate to a special internal instance group which facilitates the balancer's work.
        Instances in this group are called _resource units_. The group is scaled automatically based on incoming load
        and within limitations specified in these settings.

        For details about the concept,
        see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#lcu-scaling).
        """

    @property
    def log_options(self) -> yandex.cloud.apploadbalancer.v1.logging_pb2.LogOptions:
        """Cloud logging settings of the application load balancer."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        folder_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___LoadBalancer.Status.ValueType = ...,
        region_id: builtins.str = ...,
        network_id: builtins.str = ...,
        listeners: collections.abc.Iterable[global___Listener] | None = ...,
        allocation_policy: global___AllocationPolicy | None = ...,
        log_group_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        auto_scale_policy: global___AutoScalePolicy | None = ...,
        log_options: yandex.cloud.apploadbalancer.v1.logging_pb2.LogOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "auto_scale_policy", b"auto_scale_policy", "created_at", b"created_at", "log_options", b"log_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "auto_scale_policy", b"auto_scale_policy", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "listeners", b"listeners", "log_group_id", b"log_group_id", "log_options", b"log_options", "name", b"name", "network_id", b"network_id", "region_id", b"region_id", "security_group_ids", b"security_group_ids", "status", b"status"]) -> None: ...

global___LoadBalancer = LoadBalancer

@typing.final
class Address(google.protobuf.message.Message):
    """An endpoint address resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_IPV4_ADDRESS_FIELD_NUMBER: builtins.int
    INTERNAL_IPV4_ADDRESS_FIELD_NUMBER: builtins.int
    EXTERNAL_IPV6_ADDRESS_FIELD_NUMBER: builtins.int
    @property
    def external_ipv4_address(self) -> global___ExternalIpv4Address:
        """Public IPv4 endpoint address."""

    @property
    def internal_ipv4_address(self) -> global___InternalIpv4Address:
        """Internal IPv4 endpoint address.

        To enable the use of listeners with internal addresses, [contact support](/docs/support/overview#response-time).
        """

    @property
    def external_ipv6_address(self) -> global___ExternalIpv6Address:
        """Public IPv6 endpoint address."""

    def __init__(
        self,
        *,
        external_ipv4_address: global___ExternalIpv4Address | None = ...,
        internal_ipv4_address: global___InternalIpv4Address | None = ...,
        external_ipv6_address: global___ExternalIpv6Address | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["address", b"address", "external_ipv4_address", b"external_ipv4_address", "external_ipv6_address", b"external_ipv6_address", "internal_ipv4_address", b"internal_ipv4_address"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "external_ipv4_address", b"external_ipv4_address", "external_ipv6_address", b"external_ipv6_address", "internal_ipv4_address", b"internal_ipv4_address"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["address", b"address"]) -> typing.Literal["external_ipv4_address", "internal_ipv4_address", "external_ipv6_address"] | None: ...

global___Address = Address

@typing.final
class ExternalIpv4Address(google.protobuf.message.Message):
    """A public (external) IPv4 endpoint address resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    address: builtins.str
    """IPv4 address."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address"]) -> None: ...

global___ExternalIpv4Address = ExternalIpv4Address

@typing.final
class InternalIpv4Address(google.protobuf.message.Message):
    """An internal IPv4 endpoint address resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    address: builtins.str
    """IPv4 address."""
    subnet_id: builtins.str
    """ID of the subnet that the address belongs to."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "subnet_id", b"subnet_id"]) -> None: ...

global___InternalIpv4Address = InternalIpv4Address

@typing.final
class ExternalIpv6Address(google.protobuf.message.Message):
    """A public (external) IPv4 endpoint address resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    address: builtins.str
    """IPv6 address."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address"]) -> None: ...

global___ExternalIpv6Address = ExternalIpv6Address

@typing.final
class Location(google.protobuf.message.Message):
    """An application load balancer location resource.

    For details about the concept, see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#lb-location).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZONE_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    DISABLE_TRAFFIC_FIELD_NUMBER: builtins.int
    zone_id: builtins.str
    """ID of the availability zone where the application load balancer resides.

    Each availability zone can only be specified once.
    """
    subnet_id: builtins.str
    """ID of the subnet that the application load balancer belongs to."""
    disable_traffic: builtins.bool
    """Disables the load balancer node in the specified availability zone.

    Backends in the availability zone are not directly affected by this setting.
    They still may receive traffic from the load balancer nodes in other availability zones,
    subject to [LoadBalancingConfig.locality_aware_routing_percent] and [LoadBalancingConfig.strict_locality] settings.
    """
    def __init__(
        self,
        *,
        zone_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
        disable_traffic: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disable_traffic", b"disable_traffic", "subnet_id", b"subnet_id", "zone_id", b"zone_id"]) -> None: ...

global___Location = Location

@typing.final
class AllocationPolicy(google.protobuf.message.Message):
    """A locality settings (allocation policy) resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATIONS_FIELD_NUMBER: builtins.int
    @property
    def locations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Location]:
        """Availability zones and subnets that the application load balancer resides."""

    def __init__(
        self,
        *,
        locations: collections.abc.Iterable[global___Location] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["locations", b"locations"]) -> None: ...

global___AllocationPolicy = AllocationPolicy

@typing.final
class Listener(google.protobuf.message.Message):
    """A listener resource.

    For details about the concept, see [documentation](/docs/application-load-balancer/concepts/application-load-balancer#listener).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ENDPOINTS_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    TLS_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the listener. The name is unique within the application load balancer.
    The string length in characters is 3-63.
    """
    @property
    def endpoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Endpoint]:
        """Endpoints of the listener.

        Endpoints are defined by their IP addresses and ports.
        """

    @property
    def http(self) -> global___HttpListener:
        """Unencrypted HTTP listener settings."""

    @property
    def tls(self) -> global___TlsListener:
        """TLS-encrypted HTTP or TCP stream listener settings.

        All handlers within a listener ([TlsListener.default_handler] and [TlsListener.sni_handlers]) must be of one
        type, [HttpHandler] or [StreamHandler]. Mixing HTTP and TCP stream traffic in a TLS-encrypted listener is not
        supported.
        """

    @property
    def stream(self) -> global___StreamListener:
        """Unencrypted stream (TCP) listener settings."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        endpoints: collections.abc.Iterable[global___Endpoint] | None = ...,
        http: global___HttpListener | None = ...,
        tls: global___TlsListener | None = ...,
        stream: global___StreamListener | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["http", b"http", "listener", b"listener", "stream", b"stream", "tls", b"tls"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["endpoints", b"endpoints", "http", b"http", "listener", b"listener", "name", b"name", "stream", b"stream", "tls", b"tls"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["listener", b"listener"]) -> typing.Literal["http", "tls", "stream"] | None: ...

global___Listener = Listener

@typing.final
class Endpoint(google.protobuf.message.Message):
    """An endpoint resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESSES_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    @property
    def addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Address]:
        """Endpoint public (external) and internal addresses."""

    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """Endpoint ports."""

    def __init__(
        self,
        *,
        addresses: collections.abc.Iterable[global___Address] | None = ...,
        ports: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["addresses", b"addresses", "ports", b"ports"]) -> None: ...

global___Endpoint = Endpoint

@typing.final
class HttpListener(google.protobuf.message.Message):
    """An HTTP listener resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HANDLER_FIELD_NUMBER: builtins.int
    REDIRECTS_FIELD_NUMBER: builtins.int
    @property
    def handler(self) -> global___HttpHandler:
        """Settings for handling HTTP requests.

        Only one of `handler` and [redirects] can be specified.
        """

    @property
    def redirects(self) -> global___Redirects:
        """Redirects settings.

        Only one of `redirects` and [handler] can be specified.
        """

    def __init__(
        self,
        *,
        handler: global___HttpHandler | None = ...,
        redirects: global___Redirects | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["handler", b"handler", "redirects", b"redirects"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["handler", b"handler", "redirects", b"redirects"]) -> None: ...

global___HttpListener = HttpListener

@typing.final
class TlsListener(google.protobuf.message.Message):
    """TLS-encrypted (HTTP or TCP stream) listener resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_HANDLER_FIELD_NUMBER: builtins.int
    SNI_HANDLERS_FIELD_NUMBER: builtins.int
    @property
    def default_handler(self) -> global___TlsHandler:
        """Settings for handling requests by default, with Server Name
        Indication (SNI) not matching any of the [sni_handlers].
        """

    @property
    def sni_handlers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SniMatch]:
        """Settings for handling requests with Server Name Indication (SNI)
        matching one of [SniMatch.server_names] values.
        """

    def __init__(
        self,
        *,
        default_handler: global___TlsHandler | None = ...,
        sni_handlers: collections.abc.Iterable[global___SniMatch] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_handler", b"default_handler"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_handler", b"default_handler", "sni_handlers", b"sni_handlers"]) -> None: ...

global___TlsListener = TlsListener

@typing.final
class StreamListener(google.protobuf.message.Message):
    """A stream (TCP) listener resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HANDLER_FIELD_NUMBER: builtins.int
    @property
    def handler(self) -> global___StreamHandler:
        """Settings for handling stream (TCP) requests."""

    def __init__(
        self,
        *,
        handler: global___StreamHandler | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["handler", b"handler"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["handler", b"handler"]) -> None: ...

global___StreamListener = StreamListener

@typing.final
class Http2Options(google.protobuf.message.Message):
    """An HTTP/2 options resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONCURRENT_STREAMS_FIELD_NUMBER: builtins.int
    max_concurrent_streams: builtins.int
    """Maximum number of concurrent HTTP/2 streams in a connection."""
    def __init__(
        self,
        *,
        max_concurrent_streams: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["max_concurrent_streams", b"max_concurrent_streams"]) -> None: ...

global___Http2Options = Http2Options

@typing.final
class StreamHandler(google.protobuf.message.Message):
    """A stream (TCP) handler resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    IDLE_TIMEOUT_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """ID of the backend group processing requests. For details about the concept, see
    [documentation](/docs/application-load-balancer/concepts/backend-group).

    The backend group type, specified via [BackendGroup.backend], must be `stream`.

    To get the list of all available backend groups, make a [BackendGroupService.List] request.
    """
    @property
    def idle_timeout(self) -> google.protobuf.duration_pb2.Duration:
        """The idle timeout is duration during which no data is transmitted or received on either the upstream or downstream connection. 
        If not configured, the default idle timeout is 1 hour. Setting it to 0 disables the timeout.
        """

    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
        idle_timeout: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["idle_timeout", b"idle_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backend_group_id", b"backend_group_id", "idle_timeout", b"idle_timeout"]) -> None: ...

global___StreamHandler = StreamHandler

@typing.final
class HttpHandler(google.protobuf.message.Message):
    """An HTTP handler resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ROUTER_ID_FIELD_NUMBER: builtins.int
    HTTP2_OPTIONS_FIELD_NUMBER: builtins.int
    ALLOW_HTTP10_FIELD_NUMBER: builtins.int
    REWRITE_REQUEST_ID_FIELD_NUMBER: builtins.int
    http_router_id: builtins.str
    """ID of the HTTP router processing requests. For details about the concept, see
    [documentation](/docs/application-load-balancer/concepts/http-router).

    To get the list of all available HTTP routers, make a [HttpRouterService.List] request.
    """
    allow_http10: builtins.bool
    """Enables support for incoming HTTP/1.0 and HTTP/1.1 requests and disables it for HTTP/2 requests."""
    rewrite_request_id: builtins.bool
    """When unset, will preserve the incoming x-request-id header, otherwise would rewrite it with a new value."""
    @property
    def http2_options(self) -> global___Http2Options:
        """HTTP/2 settings.

        If specified, incoming HTTP/2 requests are supported by the listener.
        """

    def __init__(
        self,
        *,
        http_router_id: builtins.str = ...,
        http2_options: global___Http2Options | None = ...,
        allow_http10: builtins.bool = ...,
        rewrite_request_id: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allow_http10", b"allow_http10", "http2_options", b"http2_options", "protocol_settings", b"protocol_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow_http10", b"allow_http10", "http2_options", b"http2_options", "http_router_id", b"http_router_id", "protocol_settings", b"protocol_settings", "rewrite_request_id", b"rewrite_request_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["protocol_settings", b"protocol_settings"]) -> typing.Literal["http2_options", "allow_http10"] | None: ...

global___HttpHandler = HttpHandler

@typing.final
class Redirects(google.protobuf.message.Message):
    """A listener redirects resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_TO_HTTPS_FIELD_NUMBER: builtins.int
    http_to_https: builtins.bool
    """Redirects all unencrypted HTTP requests to the same URI with scheme changed to `https`.

    The setting has the same effect as a single, catch-all [HttpRoute]
    with [RedirectAction.replace_scheme] set to `https`.
    """
    def __init__(
        self,
        *,
        http_to_https: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_to_https", b"http_to_https"]) -> None: ...

global___Redirects = Redirects

@typing.final
class SniMatch(google.protobuf.message.Message):
    """A SNI handler resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SERVER_NAMES_FIELD_NUMBER: builtins.int
    HANDLER_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the SNI handler."""
    @property
    def server_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Server names that are matched by the SNI handler."""

    @property
    def handler(self) -> global___TlsHandler:
        """Settings for handling requests with Server Name Indication (SNI) matching one of [server_names] values."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        server_names: collections.abc.Iterable[builtins.str] | None = ...,
        handler: global___TlsHandler | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["handler", b"handler"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["handler", b"handler", "name", b"name", "server_names", b"server_names"]) -> None: ...

global___SniMatch = SniMatch

@typing.final
class TlsHandler(google.protobuf.message.Message):
    """A TLS-encrypted (HTTP or TCP stream) handler resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_HANDLER_FIELD_NUMBER: builtins.int
    STREAM_HANDLER_FIELD_NUMBER: builtins.int
    CERTIFICATE_IDS_FIELD_NUMBER: builtins.int
    @property
    def http_handler(self) -> global___HttpHandler:
        """HTTP handler."""

    @property
    def stream_handler(self) -> global___StreamHandler:
        """Stream (TCP) handler."""

    @property
    def certificate_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """ID's of the TLS server certificates from [Certificate Manager](/docs/certificate-manager/).

        RSA and ECDSA certificates are supported, and only the first certificate of each type is used.
        """

    def __init__(
        self,
        *,
        http_handler: global___HttpHandler | None = ...,
        stream_handler: global___StreamHandler | None = ...,
        certificate_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["handler", b"handler", "http_handler", b"http_handler", "stream_handler", b"stream_handler"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["certificate_ids", b"certificate_ids", "handler", b"handler", "http_handler", b"http_handler", "stream_handler", b"stream_handler"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["handler", b"handler"]) -> typing.Literal["http_handler", "stream_handler"] | None: ...

global___TlsHandler = TlsHandler

@typing.final
class TargetState(google.protobuf.message.Message):
    """A target state resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TargetState._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: TargetState._Status.ValueType  # 0
        HEALTHY: TargetState._Status.ValueType  # 1
        """All of the health checks specified in [HttpBackend.healthchecks] or [GrpcBackend.healthchecks] are passed
        (the number depends on the [HealthCheck.healthy_threshold] setting) and the target is ready to receive traffic.
        """
        PARTIALLY_HEALTHY: TargetState._Status.ValueType  # 2
        """Some of the health checks specified in [HttpBackend.healthchecks] or [GrpcBackend.healthchecks] failed
        (the number depends on the [HealthCheck.unhealthy_threshold] setting).
        The target is ready to receive traffic from the load balancer nodes which, based on their health checks,
        consider the target healthy.
        """
        UNHEALTHY: TargetState._Status.ValueType  # 3
        """All of the health checks specified in [HttpBackend.healthchecks] or [GrpcBackend.healthchecks] failed
        (the number depends on the [HealthCheck.unhealthy_threshold] setting) and the target is not receiving traffic.
        """
        DRAINING: TargetState._Status.ValueType  # 4
        """Target is being deleted and the application load balancer is no longer sending traffic to this target."""
        TIMEOUT: TargetState._Status.ValueType  # 5

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Supported target statuses."""

    STATUS_UNSPECIFIED: TargetState.Status.ValueType  # 0
    HEALTHY: TargetState.Status.ValueType  # 1
    """All of the health checks specified in [HttpBackend.healthchecks] or [GrpcBackend.healthchecks] are passed
    (the number depends on the [HealthCheck.healthy_threshold] setting) and the target is ready to receive traffic.
    """
    PARTIALLY_HEALTHY: TargetState.Status.ValueType  # 2
    """Some of the health checks specified in [HttpBackend.healthchecks] or [GrpcBackend.healthchecks] failed
    (the number depends on the [HealthCheck.unhealthy_threshold] setting).
    The target is ready to receive traffic from the load balancer nodes which, based on their health checks,
    consider the target healthy.
    """
    UNHEALTHY: TargetState.Status.ValueType  # 3
    """All of the health checks specified in [HttpBackend.healthchecks] or [GrpcBackend.healthchecks] failed
    (the number depends on the [HealthCheck.unhealthy_threshold] setting) and the target is not receiving traffic.
    """
    DRAINING: TargetState.Status.ValueType  # 4
    """Target is being deleted and the application load balancer is no longer sending traffic to this target."""
    TIMEOUT: TargetState.Status.ValueType  # 5

    @typing.final
    class HealthcheckStatus(google.protobuf.message.Message):
        """Health of the target."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ZONE_STATUSES_FIELD_NUMBER: builtins.int
        @property
        def zone_statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TargetState.ZoneHealthcheckStatus]:
            """Statuses of the target in its availability zones."""

        def __init__(
            self,
            *,
            zone_statuses: collections.abc.Iterable[global___TargetState.ZoneHealthcheckStatus] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["zone_statuses", b"zone_statuses"]) -> None: ...

    @typing.final
    class ZoneHealthcheckStatus(google.protobuf.message.Message):
        """Health of the target in the availability zone."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ZONE_ID_FIELD_NUMBER: builtins.int
        STATUS_FIELD_NUMBER: builtins.int
        FAILED_ACTIVE_HC_FIELD_NUMBER: builtins.int
        zone_id: builtins.str
        """ID of the availability zone."""
        status: global___TargetState.Status.ValueType
        """Status of the target in the availability zone."""
        failed_active_hc: builtins.bool
        """Indicates whether the target has been marked `UNHEALTHY` due to failing active health checks,
        which determine target statuses as configured in [HttpBackend.healthchecks] or [GrpcBackend.healthchecks].

        Currently the only type of health checks is active, as described above.
        Passive health checks, which determine the health of a target based on its responses to production requests
        (HTTP 5xx status codes, connection errors etc.), are not implemented yet.
        """
        def __init__(
            self,
            *,
            zone_id: builtins.str = ...,
            status: global___TargetState.Status.ValueType = ...,
            failed_active_hc: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["failed_active_hc", b"failed_active_hc", "status", b"status", "zone_id", b"zone_id"]) -> None: ...

    STATUS_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    @property
    def status(self) -> global___TargetState.HealthcheckStatus:
        """Health of the target, i.e. its statuses in all availability zones."""

    @property
    def target(self) -> yandex.cloud.apploadbalancer.v1.target_group_pb2.Target:
        """Target."""

    def __init__(
        self,
        *,
        status: global___TargetState.HealthcheckStatus | None = ...,
        target: yandex.cloud.apploadbalancer.v1.target_group_pb2.Target | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["status", b"status", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "target", b"target"]) -> None: ...

global___TargetState = TargetState

@typing.final
class AutoScalePolicy(google.protobuf.message.Message):
    """A resource for scaling settings of an application load balancer."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_ZONE_SIZE_FIELD_NUMBER: builtins.int
    MAX_SIZE_FIELD_NUMBER: builtins.int
    min_zone_size: builtins.int
    """Lower limit for the number of resource units in each availability zone.

    If not specified previously (using other instruments such as management console), the default value is 2.
    To revert to it, specify it explicitly.

    The minimum value is 2.
    """
    max_size: builtins.int
    """Upper limit for the total number of resource units across all availability zones.

    If a positive value is specified, it must be at least [min_zone_size] multiplied by the size of
    [AllocationPolicy.locations].

    If the value is 0, there is no upper limit.
    """
    def __init__(
        self,
        *,
        min_zone_size: builtins.int = ...,
        max_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["max_size", b"max_size", "min_zone_size", b"min_zone_size"]) -> None: ...

global___AutoScalePolicy = AutoScalePolicy



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/vpc/v1/privatelink/private_endpoint.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/vpc/v1/privatelink/private_endpoint.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/vpc/v1/privatelink/private_endpoint.proto\x12\x1fyandex.cloud.vpc.v1.privatelink\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc2\x06\n\x0fPrivateEndpoint\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12L\n\x06labels\x18\x06 \x03(\x0b\x32<.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.LabelsEntry\x12\x12\n\nnetwork_id\x18\x07 \x01(\t\x12G\n\x06status\x18\x08 \x01(\x0e\x32\x37.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.Status\x12Q\n\x07\x61\x64\x64ress\x18\t \x01(\x0b\x32@.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.EndpointAddress\x12P\n\x0b\x64ns_options\x18\n \x01(\x0b\x32;.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.DnsOptions\x12X\n\x0eobject_storage\x18\x0b \x01(\x0b\x32>.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.ObjectStorageH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x0f\n\rObjectStorage\x1a\x31\n\nDnsOptions\x12#\n\x1bprivate_dns_records_enabled\x18\x01 \x01(\x08\x1aI\n\x0f\x45ndpointAddress\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x12\n\naddress_id\x18\x03 \x01(\t\"J\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tAVAILABLE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x42\t\n\x07serviceBv\n#yandex.cloud.api.vpc.v1.privatelinkZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1/privatelink;privatelinkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.privatelink.private_endpoint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#yandex.cloud.api.vpc.v1.privatelinkZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1/privatelink;privatelink'
  _globals['_PRIVATEENDPOINT_LABELSENTRY']._loaded_options = None
  _globals['_PRIVATEENDPOINT_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_PRIVATEENDPOINT']._serialized_start=125
  _globals['_PRIVATEENDPOINT']._serialized_end=959
  _globals['_PRIVATEENDPOINT_LABELSENTRY']._serialized_start=684
  _globals['_PRIVATEENDPOINT_LABELSENTRY']._serialized_end=729
  _globals['_PRIVATEENDPOINT_OBJECTSTORAGE']._serialized_start=731
  _globals['_PRIVATEENDPOINT_OBJECTSTORAGE']._serialized_end=746
  _globals['_PRIVATEENDPOINT_DNSOPTIONS']._serialized_start=748
  _globals['_PRIVATEENDPOINT_DNSOPTIONS']._serialized_end=797
  _globals['_PRIVATEENDPOINT_ENDPOINTADDRESS']._serialized_start=799
  _globals['_PRIVATEENDPOINT_ENDPOINTADDRESS']._serialized_end=872
  _globals['_PRIVATEENDPOINT_STATUS']._serialized_start=874
  _globals['_PRIVATEENDPOINT_STATUS']._serialized_end=948
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.marketplace.metering.v1.usage_record_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class WriteUsageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRY_RUN_FIELD_NUMBER: builtins.int
    PRODUCT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    USAGE_RECORDS_FIELD_NUMBER: builtins.int
    dry_run: builtins.bool
    """Do not write usage, only validate"""
    product_instance_id: builtins.str
    """Marketplace Product Instance's ID"""
    @property
    def usage_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.marketplace.metering.v1.usage_record_pb2.UsageRecord]:
        """List of product usage records (up to 25 per request)"""

    def __init__(
        self,
        *,
        dry_run: builtins.bool = ...,
        product_instance_id: builtins.str = ...,
        usage_records: collections.abc.Iterable[yandex.cloud.marketplace.metering.v1.usage_record_pb2.UsageRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dry_run", b"dry_run", "product_instance_id", b"product_instance_id", "usage_records", b"usage_records"]) -> None: ...

global___WriteUsageRequest = WriteUsageRequest

@typing.final
class WriteUsageResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCEPTED_FIELD_NUMBER: builtins.int
    REJECTED_FIELD_NUMBER: builtins.int
    @property
    def accepted(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.marketplace.metering.v1.usage_record_pb2.AcceptedUsageRecord]:
        """List of accepted product usage records"""

    @property
    def rejected(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.marketplace.metering.v1.usage_record_pb2.RejectedUsageRecord]:
        """List of rejected product usage records (with reason)"""

    def __init__(
        self,
        *,
        accepted: collections.abc.Iterable[yandex.cloud.marketplace.metering.v1.usage_record_pb2.AcceptedUsageRecord] | None = ...,
        rejected: collections.abc.Iterable[yandex.cloud.marketplace.metering.v1.usage_record_pb2.RejectedUsageRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["accepted", b"accepted", "rejected", b"rejected"]) -> None: ...

global___WriteUsageResponse = WriteUsageResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iot/devices/v1/registry.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iot/devices/v1/registry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/iot/devices/v1/registry.proto\x12\x1byandex.cloud.iot.devices.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a\x1dyandex/cloud/validation.proto\"\xd8\x03\n\x08Registry\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x41\n\x06labels\x18\x06 \x03(\x0b\x32\x31.yandex.cloud.iot.devices.v1.Registry.LabelsEntry\x12<\n\x06status\x18\x07 \x01(\x0e\x32,.yandex.cloud.iot.devices.v1.Registry.Status\x12\x14\n\x0clog_group_id\x18\x08 \x01(\t\x12<\n\x0blog_options\x18\t \x01(\x0b\x32\'.yandex.cloud.iot.devices.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04\"\x89\x01\n\x13RegistryCertificate\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\x12\x18\n\x10\x63\x65rtificate_data\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"E\n\x0b\x44\x65viceAlias\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x14\n\x0ctopic_prefix\x18\x02 \x01(\t\x12\r\n\x05\x61lias\x18\x03 \x01(\t\"c\n\x10RegistryPassword\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xca\x01\n\x10\x44\x61taStreamExport\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bregistry_id\x18\x03 \x01(\t\x12\x19\n\x11mqtt_topic_filter\x18\x04 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x05 \x01(\t\x12\x0e\n\x06stream\x18\x06 \x01(\t\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xe0\x01\n\nLogOptions\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\x12;\n\x0clog_group_id\x18\x02 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12\x38\n\tfolder_id\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12:\n\tmin_level\x18\x04 \x01(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\r\n\x0b\x64\x65stinationBj\n\x1fyandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devicesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iot.devices.v1.registry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devices'
  _globals['_REGISTRY_LABELSENTRY']._loaded_options = None
  _globals['_REGISTRY_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LOGOPTIONS'].fields_by_name['log_group_id']._loaded_options = None
  _globals['_LOGOPTIONS'].fields_by_name['log_group_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _globals['_LOGOPTIONS'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LOGOPTIONS'].fields_by_name['folder_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _globals['_REGISTRY']._serialized_start=181
  _globals['_REGISTRY']._serialized_end=653
  _globals['_REGISTRY_LABELSENTRY']._serialized_start=520
  _globals['_REGISTRY_LABELSENTRY']._serialized_end=565
  _globals['_REGISTRY_STATUS']._serialized_start=567
  _globals['_REGISTRY_STATUS']._serialized_end=653
  _globals['_REGISTRYCERTIFICATE']._serialized_start=656
  _globals['_REGISTRYCERTIFICATE']._serialized_end=793
  _globals['_DEVICEALIAS']._serialized_start=795
  _globals['_DEVICEALIAS']._serialized_end=864
  _globals['_REGISTRYPASSWORD']._serialized_start=866
  _globals['_REGISTRYPASSWORD']._serialized_end=965
  _globals['_DATASTREAMEXPORT']._serialized_start=968
  _globals['_DATASTREAMEXPORT']._serialized_end=1170
  _globals['_LOGOPTIONS']._serialized_start=1173
  _globals['_LOGOPTIONS']._serialized_end=1397
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/mysql/v1alpha/cluster_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/mysql/v1alpha/cluster_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.mdb.mysql.v1alpha import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_backup__pb2
from yandex.cloud.mdb.mysql.v1alpha import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_cluster__pb2
from yandex.cloud.mdb.mysql.v1alpha.config import mysql5_7_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_config_dot_mysql5__7__pb2
from yandex.cloud.mdb.mysql.v1alpha import database_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_database__pb2
from yandex.cloud.mdb.mysql.v1alpha import user_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_user__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/mysql/v1alpha/cluster_service.proto\x12\x1eyandex.cloud.mdb.mysql.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/type/timeofday.proto\x1a yandex/cloud/api/operation.proto\x1a+yandex/cloud/mdb/mysql/v1alpha/backup.proto\x1a,yandex/cloud/mdb/mysql/v1alpha/cluster.proto\x1a\x34yandex/cloud/mdb/mysql/v1alpha/config/mysql5_7.proto\x1a-yandex/cloud/mdb/mysql/v1alpha/database.proto\x1a)yandex/cloud/mdb/mysql/v1alpha/user.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"j\n\x14ListClustersResponse\x12\x39\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\'.yandex.cloud.mdb.mysql.v1alpha.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xaf\x05\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8d\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.mdb.mysql.v1alpha.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12H\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.mdb.mysql.v1alpha.Cluster.Environment\x12?\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32*.yandex.cloud.mdb.mysql.v1alpha.ConfigSpec\x12\x44\n\x0e\x64\x61tabase_specs\x18\x07 \x03(\x0b\x32,.yandex.cloud.mdb.mysql.v1alpha.DatabaseSpec\x12<\n\nuser_specs\x18\x08 \x03(\x0b\x32(.yandex.cloud.mdb.mysql.v1alpha.UserSpec\x12<\n\nhost_specs\x18\t \x03(\x0b\x32(.yandex.cloud.mdb.mysql.v1alpha.HostSpec\x12\x1c\n\nnetwork_id\x18\n \x01(\tB\x08\x8a\xc8\x31\x04<=50\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xb3\x03\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8d\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.mdb.mysql.v1alpha.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12?\n\x0b\x63onfig_spec\x18\x05 \x01(\x0b\x32*.yandex.cloud.mdb.mysql.v1alpha.ConfigSpec\x12(\n\x04name\x18\x06 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x42\x61\x63kupClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x42\x61\x63kupClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xd3\x04\n\x15RestoreClusterRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12$\n\x04name\x18\x04 \x01(\tB\x16\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x1e\n\x0b\x64\x65scription\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x06 \x03(\x0b\x32\x41.yandex.cloud.mdb.mysql.v1alpha.RestoreClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12H\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32\x33.yandex.cloud.mdb.mysql.v1alpha.Cluster.Environment\x12?\n\x0b\x63onfig_spec\x18\x08 \x01(\x0b\x32*.yandex.cloud.mdb.mysql.v1alpha.ConfigSpec\x12<\n\nhost_specs\x18\t \x03(\x0b\x32(.yandex.cloud.mdb.mysql.v1alpha.HostSpec\x12\x1c\n\nnetwork_id\x18\n \x01(\tB\x08\x8a\xc8\x31\x04<=50\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x03\x10\x04\"?\n\x16RestoreClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"\xb3\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x07message\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.mdb.mysql.v1alpha.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9d\x03\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12X\n\x0cservice_type\x18\x03 \x01(\x0e\x32\x42.yandex.cloud.mdb.mysql.v1alpha.ListClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x06 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1e\n\x16\x61lways_next_page_token\x18\x08 \x01(\x08\"6\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05MYSQL\x10\x01\"k\n\x17ListClusterLogsResponse\x12\x37\n\x04logs\x18\x01 \x03(\x0b\x32).yandex.cloud.mdb.mysql.v1alpha.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"{\n\x19ListClusterBackupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x1aListClusterBackupsResponse\x12\x37\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32&.yandex.cloud.mdb.mysql.v1alpha.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"h\n\x18ListClusterHostsResponse\x12\x33\n\x05hosts\x18\x01 \x03(\x0b\x32$.yandex.cloud.mdb.mysql.v1alpha.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x80\x01\n\x16\x41\x64\x64\x43lusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x44\n\nhost_specs\x18\x02 \x03(\x0b\x32(.yandex.cloud.mdb.mysql.v1alpha.HostSpecB\x06\x82\xc8\x31\x02>0\"A\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"b\n\x19\x44\x65leteClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\"D\n\x1a\x44\x65leteClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"D\n\x1aUpdateClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\\\n\x08HostSpec\x12\x19\n\x07zone_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tsubnet_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x03 \x01(\x08\"\x84\x02\n\nConfigSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x62\n\x10mysql_config_5_7\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mysql.v1alpha.config.MysqlConfig5_7H\x00R\x0fmysqlConfig_5_7\x12<\n\tresources\x18\x03 \x01(\x0b\x32).yandex.cloud.mdb.mysql.v1alpha.Resources\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x04 \x01(\x0b\x32\x16.google.type.TimeOfDayB\x0e\n\x0cmysql_config2\xee\x16\n\x0e\x43lusterService\x12\x97\x01\n\x03Get\x12\x31.yandex.cloud.mdb.mysql.v1alpha.GetClusterRequest\x1a\'.yandex.cloud.mdb.mysql.v1alpha.Cluster\"4\x82\xd3\xe4\x93\x02.\x12,/managed-mysql/v1alpha/clusters/{cluster_id}\x12\x9a\x01\n\x04List\x12\x33.yandex.cloud.mdb.mysql.v1alpha.ListClustersRequest\x1a\x34.yandex.cloud.mdb.mysql.v1alpha.ListClustersResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/managed-mysql/v1alpha/clusters\x12\xb1\x01\n\x06\x43reate\x12\x34.yandex.cloud.mdb.mysql.v1alpha.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02$\"\x1f/managed-mysql/v1alpha/clusters:\x01*\x12\xbe\x01\n\x06Update\x12\x34.yandex.cloud.mdb.mysql.v1alpha.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x31\x32,/managed-mysql/v1alpha/clusters/{cluster_id}:\x01*\x12\xc9\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.mdb.mysql.v1alpha.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02.*,/managed-mysql/v1alpha/clusters/{cluster_id}\x12\xbe\x01\n\x05Start\x12\x33.yandex.cloud.mdb.mysql.v1alpha.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x34\"2/managed-mysql/v1alpha/clusters/{cluster_id}:start\x12\xba\x01\n\x04Stop\x12\x32.yandex.cloud.mdb.mysql.v1alpha.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x33\"1/managed-mysql/v1alpha/clusters/{cluster_id}:stop\x12\xc2\x01\n\x06\x42\x61\x63kup\x12\x34.yandex.cloud.mdb.mysql.v1alpha.BackupClusterRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2* \n\x15\x42\x61\x63kupClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x35\"3/managed-mysql/v1alpha/clusters/{cluster_id}:backup\x12\xbc\x01\n\x07Restore\x12\x35.yandex.cloud.mdb.mysql.v1alpha.RestoreClusterRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*!\n\x16RestoreClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02,\"\'/managed-mysql/v1alpha/clusters:restore:\x01*\x12\xb6\x01\n\x08ListLogs\x12\x36.yandex.cloud.mdb.mysql.v1alpha.ListClusterLogsRequest\x1a\x37.yandex.cloud.mdb.mysql.v1alpha.ListClusterLogsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-mysql/v1alpha/clusters/{cluster_id}:logs\x12\xce\x01\n\x0eListOperations\x12<.yandex.cloud.mdb.mysql.v1alpha.ListClusterOperationsRequest\x1a=.yandex.cloud.mdb.mysql.v1alpha.ListClusterOperationsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/managed-mysql/v1alpha/clusters/{cluster_id}/operations\x12\xc2\x01\n\x0bListBackups\x12\x39.yandex.cloud.mdb.mysql.v1alpha.ListClusterBackupsRequest\x1a:.yandex.cloud.mdb.mysql.v1alpha.ListClusterBackupsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/managed-mysql/v1alpha/clusters/{cluster_id}/backups\x12\xba\x01\n\tListHosts\x12\x37.yandex.cloud.mdb.mysql.v1alpha.ListClusterHostsRequest\x1a\x38.yandex.cloud.mdb.mysql.v1alpha.ListClusterHostsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-mysql/v1alpha/clusters/{cluster_id}/hosts\x12\xe4\x01\n\x08\x41\x64\x64Hosts\x12\x36.yandex.cloud.mdb.mysql.v1alpha.AddClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*0\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x43\">/managed-mysql/v1alpha/clusters/{cluster_id}/hosts:batchCreate:\x01*\x12\xee\x01\n\x0b\x44\x65leteHosts\x12\x39.yandex.cloud.mdb.mysql.v1alpha.DeleteClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*3\n\x1a\x44\x65leteClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x43\">/managed-mysql/v1alpha/clusters/{cluster_id}/hosts:batchDelete:\x01*Bn\n\"yandex.cloud.api.mdb.mysql.v1alphaZHgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha;mysqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mysql.v1alpha.cluster_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.mysql.v1alphaZHgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha;mysql'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['time']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LOGRECORD_MESSAGEENTRY']._loaded_options = None
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_options = b'8\001'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['host_names']._loaded_options = None
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['host_names']._serialized_options = b'\202\3101\002>0\212\3101\005<=253'
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_HOSTSPEC'].fields_by_name['zone_id']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['zone_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_HOSTSPEC'].fields_by_name['subnet_id']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['subnet_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002.\022,/managed-mysql/v1alpha/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/managed-mysql/v1alpha/clusters'
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002$\"\037/managed-mysql/v1alpha/clusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\00212,/managed-mysql/v1alpha/clusters/{cluster_id}:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002.*,/managed-mysql/v1alpha/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\0024\"2/managed-mysql/v1alpha/clusters/{cluster_id}:start'
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\0023\"1/managed-mysql/v1alpha/clusters/{cluster_id}:stop'
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._serialized_options = b'\262\322* \n\025BackupClusterMetadata\022\007Cluster\202\323\344\223\0025\"3/managed-mysql/v1alpha/clusters/{cluster_id}:backup'
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._serialized_options = b'\262\322*!\n\026RestoreClusterMetadata\022\007Cluster\202\323\344\223\002,\"\'/managed-mysql/v1alpha/clusters:restore:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._serialized_options = b'\202\323\344\223\0023\0221/managed-mysql/v1alpha/clusters/{cluster_id}:logs'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0029\0227/managed-mysql/v1alpha/clusters/{cluster_id}/operations'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._serialized_options = b'\202\323\344\223\0026\0224/managed-mysql/v1alpha/clusters/{cluster_id}/backups'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHosts']._serialized_options = b'\202\323\344\223\0024\0222/managed-mysql/v1alpha/clusters/{cluster_id}/hosts'
  _globals['_CLUSTERSERVICE'].methods_by_name['AddHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['AddHosts']._serialized_options = b'\262\322*0\n\027AddClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002C\">/managed-mysql/v1alpha/clusters/{cluster_id}/hosts:batchCreate:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteHosts']._serialized_options = b'\262\322*3\n\032DeleteClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002C\">/managed-mysql/v1alpha/clusters/{cluster_id}/hosts:batchDelete:\001*'
  _globals['_GETCLUSTERREQUEST']._serialized_start=554
  _globals['_GETCLUSTERREQUEST']._serialized_end=607
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=610
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=754
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=756
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=862
  _globals['_CREATECLUSTERREQUEST']._serialized_start=865
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1552
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1507
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1552
  _globals['_CREATECLUSTERMETADATA']._serialized_start=1554
  _globals['_CREATECLUSTERMETADATA']._serialized_end=1597
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1600
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2035
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1507
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1552
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2037
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2080
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2082
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2138
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2140
  _globals['_DELETECLUSTERMETADATA']._serialized_end=2183
  _globals['_BACKUPCLUSTERREQUEST']._serialized_start=2185
  _globals['_BACKUPCLUSTERREQUEST']._serialized_end=2241
  _globals['_BACKUPCLUSTERMETADATA']._serialized_start=2243
  _globals['_BACKUPCLUSTERMETADATA']._serialized_end=2286
  _globals['_RESTORECLUSTERREQUEST']._serialized_start=2289
  _globals['_RESTORECLUSTERREQUEST']._serialized_end=2884
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_start=1507
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_end=1552
  _globals['_RESTORECLUSTERMETADATA']._serialized_start=2886
  _globals['_RESTORECLUSTERMETADATA']._serialized_end=2949
  _globals['_LOGRECORD']._serialized_start=2952
  _globals['_LOGRECORD']._serialized_end=3131
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_start=3085
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_end=3131
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_start=3134
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_end=3547
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=3493
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=3547
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_start=3549
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_end=3656
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=3658
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=3784
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=3786
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=3897
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_start=3899
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_end=4022
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_start=4024
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_end=4134
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=4136
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=4257
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=4259
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=4363
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_start=4366
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_end=4494
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_start=4496
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_end=4561
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_start=4563
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_end=4661
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_start=4663
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_end=4731
  _globals['_STARTCLUSTERREQUEST']._serialized_start=4733
  _globals['_STARTCLUSTERREQUEST']._serialized_end=4788
  _globals['_STARTCLUSTERMETADATA']._serialized_start=4790
  _globals['_STARTCLUSTERMETADATA']._serialized_end=4832
  _globals['_STOPCLUSTERREQUEST']._serialized_start=4834
  _globals['_STOPCLUSTERREQUEST']._serialized_end=4888
  _globals['_STOPCLUSTERMETADATA']._serialized_start=4890
  _globals['_STOPCLUSTERMETADATA']._serialized_end=4931
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_start=4933
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_end=5001
  _globals['_HOSTSPEC']._serialized_start=5003
  _globals['_HOSTSPEC']._serialized_end=5095
  _globals['_CONFIGSPEC']._serialized_start=5098
  _globals['_CONFIGSPEC']._serialized_end=5358
  _globals['_CLUSTERSERVICE']._serialized_start=5361
  _globals['_CLUSTERSERVICE']._serialized_end=8287
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.greenplum.v1.resource_groups_pb2
import yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ResourceGroupServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.ListResourceGroupsRequest,
        yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.ListResourceGroupsResponse,
    ]
    """List all resource group"""

    GetAtRevision: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.GetResourceGroupAtRevisionRequest,
        yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup,
    ]
    """Returns the specified resource group at revision."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.CreateResourceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates resource group"""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.UpdateResourceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update resource group"""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.DeleteResourceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete resource group"""

class ResourceGroupServiceAsyncStub:
    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.ListResourceGroupsRequest,
        yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.ListResourceGroupsResponse,
    ]
    """List all resource group"""

    GetAtRevision: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.GetResourceGroupAtRevisionRequest,
        yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup,
    ]
    """Returns the specified resource group at revision."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.CreateResourceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates resource group"""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.UpdateResourceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update resource group"""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.DeleteResourceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete resource group"""

class ResourceGroupServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.ListResourceGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.ListResourceGroupsResponse, collections.abc.Awaitable[yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.ListResourceGroupsResponse]]:
        """List all resource group"""

    @abc.abstractmethod
    def GetAtRevision(
        self,
        request: yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.GetResourceGroupAtRevisionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup, collections.abc.Awaitable[yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup]]:
        """Returns the specified resource group at revision."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.CreateResourceGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates resource group"""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.UpdateResourceGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update resource group"""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2.DeleteResourceGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete resource group"""

def add_ResourceGroupServiceServicer_to_server(servicer: ResourceGroupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.k8s.marketplace.v1.helm_release_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListHelmReleasesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """The ID of the Kubernetes cluster to list Helm releases from."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned."""
    page_token: builtins.str
    """Token for pagination to retrieve the next page of results."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListHelmReleasesRequest = ListHelmReleasesRequest

@typing.final
class ListHelmReleasesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HELM_RELEASES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for retrieving the next page of Helm releases."""
    @property
    def helm_releases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.k8s.marketplace.v1.helm_release_pb2.HelmRelease]:
        """List of Helm releases in the Kubernetes cluster."""

    def __init__(
        self,
        *,
        helm_releases: collections.abc.Iterable[yandex.cloud.k8s.marketplace.v1.helm_release_pb2.HelmRelease] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["helm_releases", b"helm_releases", "next_page_token", b"next_page_token"]) -> None: ...

global___ListHelmReleasesResponse = ListHelmReleasesResponse

@typing.final
class GetHelmReleaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """The ID of the Helm release to retrieve."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___GetHelmReleaseRequest = GetHelmReleaseRequest

@typing.final
class InstallHelmReleaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PRODUCT_VERSION_ID_FIELD_NUMBER: builtins.int
    USER_VALUES_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """The ID of the Kubernetes cluster where the Helm release is to be installed."""
    product_version_id: builtins.str
    """The product version ID to install."""
    @property
    def user_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValueWithKey]:
        """User-defined values for the Helm chart during installation."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        product_version_id: builtins.str = ...,
        user_values: collections.abc.Iterable[global___ValueWithKey] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "product_version_id", b"product_version_id", "user_values", b"user_values"]) -> None: ...

global___InstallHelmReleaseRequest = InstallHelmReleaseRequest

@typing.final
class InstallHelmReleaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    HELM_RELEASE_ID_FIELD_NUMBER: builtins.int
    PRODUCT_VERSION_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """The ID of the Kubernetes cluster where the Helm release is being installed."""
    helm_release_id: builtins.str
    """The ID of the Helm release being installed."""
    product_version_id: builtins.str
    """The ID of the product version being deployed."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        helm_release_id: builtins.str = ...,
        product_version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "helm_release_id", b"helm_release_id", "product_version_id", b"product_version_id"]) -> None: ...

global___InstallHelmReleaseMetadata = InstallHelmReleaseMetadata

@typing.final
class UpdateHelmReleaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PRODUCT_VERSION_ID_FIELD_NUMBER: builtins.int
    USER_VALUES_FIELD_NUMBER: builtins.int
    id: builtins.str
    """The ID of the Helm release to update."""
    product_version_id: builtins.str
    """The ID of the new product version for the release."""
    @property
    def user_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValueWithKey]:
        """Custom user values to apply during the update."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        product_version_id: builtins.str = ...,
        user_values: collections.abc.Iterable[global___ValueWithKey] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "product_version_id", b"product_version_id", "user_values", b"user_values"]) -> None: ...

global___UpdateHelmReleaseRequest = UpdateHelmReleaseRequest

@typing.final
class UpdateHelmReleaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    HELM_RELEASE_ID_FIELD_NUMBER: builtins.int
    PRODUCT_VERSION_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """The ID of the Kubernetes cluster where the Helm release is being updated."""
    helm_release_id: builtins.str
    """The ID of the Helm release being updated."""
    product_version_id: builtins.str
    """The ID of the new product version to update the Helm release to."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        helm_release_id: builtins.str = ...,
        product_version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "helm_release_id", b"helm_release_id", "product_version_id", b"product_version_id"]) -> None: ...

global___UpdateHelmReleaseMetadata = UpdateHelmReleaseMetadata

@typing.final
class UninstallHelmReleaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """The ID of the Helm release to retrieve."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___UninstallHelmReleaseRequest = UninstallHelmReleaseRequest

@typing.final
class UninstallHelmReleaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    HELM_RELEASE_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """The ID of the Kubernetes cluster where the release is being uninstalled."""
    helm_release_id: builtins.str
    """The ID of the Helm release being uninstalled."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        helm_release_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "helm_release_id", b"helm_release_id"]) -> None: ...

global___UninstallHelmReleaseMetadata = UninstallHelmReleaseMetadata

@typing.final
class ValueWithKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    """The key associated with the value."""
    @property
    def value(self) -> global___Value:
        """The value associated with the key."""

    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: global___Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

global___ValueWithKey = ValueWithKey

@typing.final
class Value(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPED_VALUE_FIELD_NUMBER: builtins.int
    typed_value: builtins.str
    """The typed string value."""
    def __init__(
        self,
        *,
        typed_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["typed_value", b"typed_value", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["typed_value", b"typed_value", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["value", b"value"]) -> typing.Literal["typed_value"] | None: ...

global___Value = Value



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/kms/v1/symmetric_key.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/kms/v1/symmetric_key.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/kms/v1/symmetric_key.proto\x12\x13yandex.cloud.kms.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xfa\x04\n\x0cSymmetricKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12=\n\x06labels\x18\x06 \x03(\x0b\x32-.yandex.cloud.kms.v1.SymmetricKey.LabelsEntry\x12\x38\n\x06status\x18\x07 \x01(\x0e\x32(.yandex.cloud.kms.v1.SymmetricKey.Status\x12\x41\n\x0fprimary_version\x18\x08 \x01(\x0b\x32(.yandex.cloud.kms.v1.SymmetricKeyVersion\x12\x42\n\x11\x64\x65\x66\x61ult_algorithm\x18\t \x01(\x0e\x32\'.yandex.cloud.kms.v1.SymmetricAlgorithm\x12.\n\nrotated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0frotation_period\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03\"\x92\x03\n\x13SymmetricKeyVersion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06key_id\x18\x02 \x01(\t\x12?\n\x06status\x18\x03 \x01(\x0e\x32/.yandex.cloud.kms.v1.SymmetricKeyVersion.Status\x12:\n\talgorithm\x18\x04 \x01(\x0e\x32\'.yandex.cloud.kms.v1.SymmetricAlgorithm\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07primary\x18\x06 \x01(\x08\x12.\n\ndestroy_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rhosted_by_hsm\x18\x08 \x01(\x08\"Z\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x1d\n\x19SCHEDULED_FOR_DESTRUCTION\x10\x02\x12\r\n\tDESTROYED\x10\x03*q\n\x12SymmetricAlgorithm\x12#\n\x1fSYMMETRIC_ALGORITHM_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x41\x45S_128\x10\x01\x12\x0b\n\x07\x41\x45S_192\x10\x02\x12\x0b\n\x07\x41\x45S_256\x10\x03\x12\x0f\n\x0b\x41\x45S_256_HSM\x10\x04\x42V\n\x17yandex.cloud.api.kms.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1;kmsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.kms.v1.symmetric_key_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.kms.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1;kms'
  _globals['_SYMMETRICKEY_LABELSENTRY']._loaded_options = None
  _globals['_SYMMETRICKEY_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SYMMETRICALGORITHM']._serialized_start=1171
  _globals['_SYMMETRICALGORITHM']._serialized_end=1284
  _globals['_SYMMETRICKEY']._serialized_start=130
  _globals['_SYMMETRICKEY']._serialized_end=764
  _globals['_SYMMETRICKEY_LABELSENTRY']._serialized_start=645
  _globals['_SYMMETRICKEY_LABELSENTRY']._serialized_end=690
  _globals['_SYMMETRICKEY_STATUS']._serialized_start=692
  _globals['_SYMMETRICKEY_STATUS']._serialized_end=764
  _globals['_SYMMETRICKEYVERSION']._serialized_start=767
  _globals['_SYMMETRICKEYVERSION']._serialized_end=1169
  _globals['_SYMMETRICKEYVERSION_STATUS']._serialized_start=1079
  _globals['_SYMMETRICKEYVERSION_STATUS']._serialized_end=1169
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.backup.v1.policy_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListPoliciesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID. Either Folder ID or Compute Cloud instance ID should be set."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID. Either Folder ID or Compute Cloud instance ID should be set."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "folder_id", b"folder_id"]) -> None: ...

global___ListPoliciesRequest = ListPoliciesRequest

@typing.final
class ListPoliciesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICIES_FIELD_NUMBER: builtins.int
    @property
    def policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.backup.v1.policy_pb2.Policy]: ...
    def __init__(
        self,
        *,
        policies: collections.abc.Iterable[yandex.cloud.backup.v1.policy_pb2.Policy] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policies", b"policies"]) -> None: ...

global___ListPoliciesResponse = ListPoliciesResponse

@typing.final
class CreatePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID."""
    name: builtins.str
    """Policy name."""
    @property
    def settings(self) -> yandex.cloud.backup.v1.policy_pb2.PolicySettings: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        settings: yandex.cloud.backup.v1.policy_pb2.PolicySettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "name", b"name", "settings", b"settings"]) -> None: ...

global___CreatePolicyRequest = CreatePolicyRequest

@typing.final
class CreatePolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___CreatePolicyMetadata = CreatePolicyMetadata

@typing.final
class GetPolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___GetPolicyRequest = GetPolicyRequest

@typing.final
class UpdatePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    @property
    def settings(self) -> yandex.cloud.backup.v1.policy_pb2.PolicySettings: ...
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        settings: yandex.cloud.backup.v1.policy_pb2.PolicySettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id", "settings", b"settings"]) -> None: ...

global___UpdatePolicyRequest = UpdatePolicyRequest

@typing.final
class UpdatePolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___UpdatePolicyMetadata = UpdatePolicyMetadata

@typing.final
class DeletePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___DeletePolicyRequest = DeletePolicyRequest

@typing.final
class DeletePolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___DeletePolicyMetadata = DeletePolicyMetadata

@typing.final
class ApplyPolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "policy_id", b"policy_id"]) -> None: ...

global___ApplyPolicyRequest = ApplyPolicyRequest

@typing.final
class ApplyPolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "policy_id", b"policy_id"]) -> None: ...

global___ApplyPolicyMetadata = ApplyPolicyMetadata

@typing.final
class ListApplicationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    SHOW_PROCESSING_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID."""
    policy_id: builtins.str
    """Policy ID."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    show_processing: builtins.bool
    """If true, also returns applications that in the process of binding."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        policy_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
        show_processing: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "folder_id", b"folder_id", "id", b"id", "policy_id", b"policy_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "folder_id", b"folder_id", "id", b"id", "policy_id", b"policy_id", "show_processing", b"show_processing"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["id", b"id"]) -> typing.Literal["folder_id", "policy_id", "compute_instance_id"] | None: ...

global___ListApplicationsRequest = ListApplicationsRequest

@typing.final
class ListApplicationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATIONS_FIELD_NUMBER: builtins.int
    @property
    def applications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.backup.v1.policy_pb2.PolicyApplication]: ...
    def __init__(
        self,
        *,
        applications: collections.abc.Iterable[yandex.cloud.backup.v1.policy_pb2.PolicyApplication] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["applications", b"applications"]) -> None: ...

global___ListApplicationsResponse = ListApplicationsResponse

@typing.final
class ExecuteRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "policy_id", b"policy_id"]) -> None: ...

global___ExecuteRequest = ExecuteRequest

@typing.final
class ExecuteMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    PROGRESS_PERCENTAGE_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    progress_percentage: builtins.float
    """Progress of the backup process."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
        progress_percentage: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "policy_id", b"policy_id", "progress_percentage", b"progress_percentage"]) -> None: ...

global___ExecuteMetadata = ExecuteMetadata

@typing.final
class RevokeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "policy_id", b"policy_id"]) -> None: ...

global___RevokeRequest = RevokeRequest

@typing.final
class RevokeMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "policy_id", b"policy_id"]) -> None: ...

global___RevokeMetadata = RevokeMetadata
